@@ -28,7 +28,6 @@ testinfra_hosts = testinfra.utils.ansible_runner.AnsibleRunner(
 @pytest.mark.parametrize(
     'path',
     ['barbican',
-     'ceph',
      'cinder',
      'cloudkitty',
      'designate',
@@ -63,7 +62,6 @@ def test_service_config_directory(host, path):
 @pytest.mark.parametrize(
     'path',
     ['barbican.conf',
-     'ceph.conf',
      'cinder.conf',
      'cloudkitty.conf',
      'designate.conf',
